@@ -9,7 +9,7 @@
 
 from detector_connector import DetectorConnector
 
-from .shift_definition import ShiftAnalyzeResult
+from .shift_analyze_result import ShiftAnalyzeResult
 
 
 class ShiftDetectorConnector(DetectorConnector):
